@@ -25,14 +25,11 @@
 #endif /* HAVE_LIBTIFF */
 #include <glib/gi18n.h>
 #include <gthumb.h>
-#include "enum-types.h"
+#include "cairo-io-enum-types.h"
 #include "gth-image-saver-tiff.h"
 #include "preferences.h"
 
 
-G_DEFINE_TYPE (GthImageSaverTiff, gth_image_saver_tiff, GTH_TYPE_IMAGE_SAVER)
-
-
 struct _GthImageSaverTiffPrivate {
 	GSettings  *settings;
 	GtkBuilder *builder;
@@ -40,6 +37,12 @@ struct _GthImageSaverTiffPrivate {
 };
 
 
+G_DEFINE_TYPE_WITH_CODE (GthImageSaverTiff,
+			 gth_image_saver_tiff,
+			 GTH_TYPE_IMAGE_SAVER,
+			 G_ADD_PRIVATE (GthImageSaverTiff))
+
+
 static void
 gth_image_saver_tiff_finalize (GObject *object)
 {
@@ -553,8 +556,6 @@ gth_image_saver_tiff_class_init (GthImageSaverTiffClass *klass)
 	GObjectClass       *object_class;
 	GthImageSaverClass *image_saver_class;
 
-	g_type_class_add_private (klass, sizeof (GthImageSaverTiffPrivate));
-
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gth_image_saver_tiff_finalize;
 
@@ -574,7 +575,7 @@ gth_image_saver_tiff_class_init (GthImageSaverTiffClass *klass)
 static void
 gth_image_saver_tiff_init (GthImageSaverTiff *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE_SAVER_TIFF, GthImageSaverTiffPrivate);
+	self->priv = gth_image_saver_tiff_get_instance_private (self);
 	self->priv->settings = g_settings_new (GTHUMB_IMAGE_SAVERS_TIFF_SCHEMA);
 	self->priv->builder = NULL;
 	self->priv->default_ext = NULL;
