@@ -24,7 +24,6 @@
 
 #include <gthumb.h>
 
-gpointer  file_tools__gth_browser_file_list_key_press_cb    (GthBrowser  *browser,
-						   	     GdkEventKey *event);
+void file_tools__gth_browser_construct_cb (GthBrowser *browser);
 
 #endif /* CALLBACKS_H */
