@@ -21,6 +21,7 @@
 
 #include <config.h>
 #include "gth-reset-orientation-task.h"
+#include "rotation-utils.h"
 
 
 struct _GthResetOrientationTaskPrivate {
@@ -66,22 +67,20 @@ transform_next_file (GthResetOrientationTask *self)
 
 
 static void
-write_metadata_ready_cb (GObject      *source_object,
-	 	 	 GAsyncResult *result,
-	 	 	 gpointer      user_data)
+transform_file_ready_cb (GObject *source_object,
+			 GAsyncResult *res,
+			 gpointer user_data)
 {
 	GthResetOrientationTask *self = user_data;
-	GFile                   *parent;
-	GList                   *file_list;
-	GError                  *error = NULL;
+	GError *error = NULL;
 
-	if (! _g_write_metadata_finish (result, &error)) {
+	if (!apply_transformation_finish (res, &error)) {
 		gth_task_completed (GTH_TASK (self), error);
 		return;
 	}
 
-	parent = g_file_get_parent (self->priv->file_data->file);
-	file_list = g_list_append (NULL, self->priv->file_data->file);
+	GFile *parent = g_file_get_parent (self->priv->file_data->file);
+	GList *file_list = g_list_append (NULL, self->priv->file_data->file);
 	gth_monitor_folder_changed (gth_main_get_default_monitor (),
 				    parent,
 				    file_list,
@@ -100,7 +99,6 @@ file_info_ready_cb (GList    *files,
 		    gpointer  user_data)
 {
 	GthResetOrientationTask *self = user_data;
-	GthMetadata         *metadata;
 
 	if (error != NULL) {
 		gth_task_completed (GTH_TASK (self), error);
@@ -116,17 +114,12 @@ file_info_ready_cb (GList    *files,
 			   FALSE,
 			   (double) (self->priv->n_image + 1) / (self->priv->n_images + 1));
 
-	metadata = g_object_new (GTH_TYPE_METADATA, "raw", "1", NULL);
-	g_file_info_set_attribute_object (self->priv->file_data->info, "Exif::Image::Orientation", G_OBJECT (metadata));
-
-	_g_write_metadata_async (files,
-				 GTH_METADATA_WRITE_FORCE_EMBEDDED,
-				 "*",
-				 gth_task_get_cancellable (GTH_TASK (self)),
-				 write_metadata_ready_cb,
-				 self);
-
-	g_object_unref (metadata);
+	apply_transformation_async (self->priv->file_data,
+		GTH_TRANSFORM_NONE,
+		GTH_TRANSFORM_FLAG_RESET,
+		gth_task_get_cancellable (GTH_TASK (self)),
+		transform_file_ready_cb,
+		self);
 }
 
 
@@ -145,7 +138,8 @@ transform_current_file (GthResetOrientationTask *self)
 	singleton = g_list_append (NULL, g_object_ref (file));
 	_g_query_all_metadata_async (singleton,
 				     GTH_LIST_DEFAULT,
-				     "*",
+				     (G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
+				      G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME),
 				     gth_task_get_cancellable (GTH_TASK (self)),
 				     file_info_ready_cb,
 				     self);
