@@ -261,7 +261,7 @@ gth_browser_activate_paste_image (GSimpleAction	*action,
 	if (viewer_page == NULL)
 		return;
 
-	gth_image_viewer_page_paste_image (viewer_page);
+	gth_image_viewer_page_paste_image (viewer_page, NULL);
 }
 
 
@@ -543,4 +543,3 @@ gth_browser_activate_scroll_to_center (GSimpleAction	*action,
 	image_viewer = GTH_IMAGE_VIEWER (gth_image_viewer_page_get_image_viewer (viewer_page));
 	gth_image_viewer_scroll_to_center (image_viewer);
 }
-
