@@ -43,6 +43,7 @@ static GthTemplateCode Image_Header_Special_Codes[] = {
 	{ GTH_TEMPLATE_CODE_TYPE_SIMPLE, N_("Current image number"), 'i', 0 },
 	{ GTH_TEMPLATE_CODE_TYPE_SIMPLE, N_("Total number of images"), 'I', 0 },
 	{ GTH_TEMPLATE_CODE_TYPE_SIMPLE, N_("Original filename"), 'F', 0 },
+	{ GTH_TEMPLATE_CODE_TYPE_SIMPLE, N_("Title"), 'T', 0 },
 	{ GTH_TEMPLATE_CODE_TYPE_SIMPLE, N_("Comment"), 'C', 0 },
 	{ GTH_TEMPLATE_CODE_TYPE_DATE, N_("Current date"), 'D', 1 },
 };
@@ -296,8 +297,12 @@ text_preview_cb (TemplateFlags   flags,
 		_g_string_append_markup_escaped (result, "%s", _("Comment"));
 		break;
 
+	case 'T':
+		_g_string_append_markup_escaped (result, "%s", _("Title"));
+		break;
+
 	case 'L':
-		_g_string_append_markup_escaped (result, "%s", g_file_info_get_edit_name (data->location->info));
+		_g_string_append_markup_escaped (result, "%s", _g_file_info_get_edit_name (data->location->info));
 		break;
 
 	default:
